@@ -207,14 +207,17 @@ class ExperimentIterableDataset(IterableDataset):
         """If non-default value of total_size_limit was not passed,
         set Sample Size Limit based on T-Shirt size if code is run on training pod:
         For memory < 32 (T-Shirts: XS,S, M) default is 100MB,
-        For memory >= 32 or runs outside pod default is 1GB
+        For memory = 32 (T-Shirt L) default is 0.7GB,
+        For memory > 32 (T-Shirt XL) or runs outside pod default is 1GB.
         """
         if size_limit == DEFAULT_SAMPLE_SIZE_LIMIT:
             size_mem = int(findall(r'[0-9]+', os.environ.get('MEM', '32'))[0])
-            if size_mem >= 32:
-                self.total_size_limit = DEFAULT_SAMPLE_SIZE_LIMIT     # 1GB in bytes
+            if size_mem > 32:
+                self.total_size_limit = DEFAULT_SAMPLE_SIZE_LIMIT             # 1GB in bytes
+            elif size_mem == 32:
+                self.total_size_limit = int(0.7 * DEFAULT_SAMPLE_SIZE_LIMIT)  # 0.7GB in bytes
             else:
-                self.total_size_limit = DEFAULT_REDUCED_SAMPLE_SIZE_LIMIT      # 100MB in bytes
+                self.total_size_limit = DEFAULT_REDUCED_SAMPLE_SIZE_LIMIT     # 100MB in bytes
         else:
             self.total_size_limit = size_limit
 
