@@ -26,26 +26,28 @@ class ExperimentDataLoader(DataLoader):
     """Experiment Data Loader based on torch DataLoader.
     It interacts with the Flight Service to provide data batch stream
 
-    Example
-    -------
-    >>> experiment_metadata = {
-    >>>     "prediction_column": 'species',
-    >>>     "prediction_type": "classification",
-    >>>     "project_id": os.environ.get('PROJECT_ID'),
-    >>>     'wml_credentials': wml_credentials
-    >>> }
+    **Example**
 
-    >>> connection = DataConnection(data_asset_id='5d99c11a-2060-4ef6-83d5-dc593c6455e2')
+    .. code-block:: python
+
+        experiment_metadata = {
+            "prediction_column": 'species',
+            "prediction_type": "classification",
+            "project_id": os.environ.get('PROJECT_ID'),
+            'wml_credentials': wml_credentials
+        }
+
+        connection = DataConnection(data_asset_id='5d99c11a-2060-4ef6-83d5-dc593c6455e2')
 
 
-    >>> iterable_dataset = ExperimentIterableDataset(connection=connection,
-    >>>                                              enable_sampling=False,
-    >>>                                              experiment_metadata=experiment_metadata)
+        iterable_dataset = ExperimentIterableDataset(connection=connection,
+                                                     enable_sampling=False,
+                                                     experiment_metadata=experiment_metadata)
 
-    >>> data_loader = ExperimentDataLoader(dataset=iterable_dataset)
+        data_loader = ExperimentDataLoader(dataset=iterable_dataset)
 
-    >>> for data in data_loader:
-    >>>     print(data)
+        for data in data_loader:
+            print(data)
     """
 
     def __init__(self, dataset: "IterableDataset"):
