@@ -1,4 +1,4 @@
-#  (C) Copyright IBM Corp. 2021.
+#  (C) Copyright IBM Corp. 2021-2023.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -47,9 +47,7 @@ __all__ = [
 
 
 class BaseDeployment(ABC):
-    """
-    Base abstract class for Deployment.
-    """
+    """Base abstract class for Deployment."""
 
     def __init__(self,
                  deployment_type: str,
@@ -148,28 +146,25 @@ class BaseDeployment(ABC):
 
     @abstractmethod
     def create(self, **kwargs):
-        """
-        Create deployment from a model.
+        """Create deployment from a model.
 
-        Parameters
-        ----------
-        model: str, required
-            AutoAI model name.
+        :param model: AutoAI model name
+        :type model: str
 
-        deployment_name: str, required
-            Name of the deployment
+        :param deployment_name: name of the deployment
+        :type deployment_name: str
 
-        training_data: Union['pandas.DataFrame', 'numpy.ndarray'], optional
-            Training data for the model
+        :param training_data: training data for the model
+        :type training_data: pandas.DataFrame or numpy.ndarray, optional
 
-        training_target: Union['pandas.DataFrame', 'numpy.ndarray'], optional
-            Target/label data for the model
+        :param training_target: target/label data for the model
+        :type training_target: pandas.DataFrame or numpy.ndarray, optional
 
-        metadata: dictionary, optional
-            Model meta properties.
+        :param metadata: model meta properties
+        :type metadata: dict, optional
 
-        experiment_run_id: str, optional
-            ID of a training/experiment (only applicable for AutoAI deployments)
+        :param experiment_run_id: ID of a training/experiment (only applicable for AutoAI deployments)
+        :type experiment_run_id: str, optional
         """
 
         if kwargs.get('serving_name'):
@@ -463,13 +458,10 @@ class BaseDeployment(ABC):
 
     @abstractmethod
     def score(self, **kwargs):
-        """
-        Scoring on WML. Payload is passed to the WML scoring endpoint where model have been deployed.
+        """Scoring on WML. Payload is passed to the WML scoring endpoint where model have been deployed.
 
-        Parameters
-        ----------
-        payload: pandas.DataFrame, required
-            DataFrame with data to test the model.
+        :param payload: data to test the model
+        :type payload: pandas.DataFrame
         """
 
         if isinstance(kwargs['payload'], DataFrame):
@@ -508,16 +500,13 @@ class BaseDeployment(ABC):
 
     @abstractmethod
     def delete(self, **kwargs):
-        """
-        Delete deployment on WML.
+        """Delete deployment on WML.
 
-        Parameters
-        ----------
-        deployment_id: str, optional
-            ID of the deployment to delete. If empty, current deployment will be deleted.
+        :param deployment_id: ID of the deployment to delete, if empty, current deployment will be deleted
+        :type deployment_id: str, optional
 
-        deployment_type: str, required
-            Type of the deployment: [online, batch]
+        :param deployment_type: type of the deployment: [online, batch]
+        :type deployment_type: str
         """
         if kwargs['deployment_id'] is None:
             self._target_workspace.wml_client.deployments.delete(self.id)
@@ -538,16 +527,14 @@ class BaseDeployment(ABC):
 
     @abstractmethod
     def list(self, **kwargs):
-        """
-        List WML deployments.
+        """List WML deployments.
 
-        Parameters
-        ----------
-        limit: int, optional
-            Set the limit of how many deployments to list. Default is None (all deployments should be fetched)
+        :param limit: set the limit of how many deployments to list,
+            default is `None` (all deployments should be fetched)
+        :type limit: int, optional
 
-        deployment_type: str, required
-            Type of the deployment: [online, batch]
+        :param deployment_type: type of the deployment: [online, batch]
+        :type deployment_type: str
         """
         deployments = self._target_workspace.wml_client.deployments.get_details(limit=kwargs['limit'])
         columns = [
@@ -573,16 +560,13 @@ class BaseDeployment(ABC):
 
     @abstractmethod
     def get(self, **kwargs):
-        """
-        Get WML deployment.
+        """Get WML deployment.
 
-        Parameters
-        ----------
-        deployment_id: str, required
-            ID of the deployment to work with.
+        :param deployment_id: ID of the deployment to work with
+        :type deployment_id: str
 
-        deployment_type: str, required
-            Type of the deployment: [online, batch]
+        :param deployment_type: type of the deployment: [online, batch]
+        :type deployment_type: str
         """
         deployment_details = self._target_workspace.wml_client.deployments.get_details(
             deployment_uid=kwargs['deployment_id'])
@@ -605,20 +589,16 @@ class BaseDeployment(ABC):
     def _publish_model(self,
                        pipeline_model: Union['Pipeline', str],
                        meta_props: Dict) -> str:
-        """
-        Publish model into WML.
+        """Publish model into WML.
 
-        Parameters
-        ----------
-        pipeline_model: Pipeline or str, required
-            Model of the pipeline to publish
+        :param pipeline_model: model of the pipeline to publish
+        :type pipeline_model: Pipeline or str
 
-        meta_props: dictionary, required
-            Model meta properties.
+        :param meta_props: model meta properties
+        :type meta_props: dict
 
-        Returns
-        -------
-        String with asset_id.
+        :return: asset id
+        :rtype: str
         """
 
         # Note: publish model to project and then promote to space
