@@ -1,4 +1,4 @@
-#  (C) Copyright IBM Corp. 2021.
+#  (C) Copyright IBM Corp. 2021-2023.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -42,29 +42,26 @@ __all__ = [
 
 
 class Batch(BaseDeployment):
-    """
-    The Batch Deployment class.
+    """The Batch Deployment class.
     With this class object you can manage any batch deployment.
 
-    Parameters
-    ----------
-    source_wml_credentials: dictionary, required
-        Credentials to Watson Machine Learning instance where training was performed.
+    :param source_wml_credentials: credentials to Watson Machine Learning instance where training was performed
+    :type source_wml_credentials: dict
 
-    source_project_id: str, optional
-        ID of the Watson Studio project where training was performed.
+    :param source_project_id: ID of the Watson Studio project where training was performed
+    :type source_project_id: str, optional
 
-    source_space_id: str, optional
-        ID of the Watson Studio Space where training was performed.
+    :param source_space_id: ID of the Watson Studio Space where training was performed
+    :type source_space_id: str, optional
 
-    target_wml_credentials: dictionary, required
-        Credentials to Watson Machine Learning instance where you want to deploy.
+    :param target_wml_credentials: credentials to Watson Machine Learning instance where you want to deploy
+    :type target_wml_credentials: dict
 
-    target_project_id: str, optional
-        ID of the Watson Studio project where you want to deploy.
+    :param target_project_id: ID of the Watson Studio project where you want to deploy
+    :type target_project_id: str, optional
 
-    target_space_id: str, optional
-        ID of the Watson Studio Space where you want to deploy.
+    :param target_space_id: ID of the Watson Studio Space where you want to deploy
+    :type target_space_id: str, optional
     """
 
     def __init__(self,
@@ -111,51 +108,50 @@ class Batch(BaseDeployment):
                training_data: Optional[Union['DataFrame', 'ndarray']] = None,
                training_target: Optional[Union['DataFrame', 'ndarray']] = None,
                experiment_run_id: Optional[str] = None) -> None:
-        """
-        Create deployment from a model.
+        """Create deployment from a model.
 
-        Parameters
-        ----------
-        model: str, required
-            AutoAI model name.
+        :param model: AutoAI model name
+        :type model: str
 
-        deployment_name: str, required
-            Name of the deployment
+        :param deployment_name: name of the deployment
+        :type deployment_name: str
 
-        training_data: Union['pandas.DataFrame', 'numpy.ndarray'], optional
-            Training data for the model
+        :param training_data: training data for the model
+        :type training_data: pandas.DataFrame or numpy.ndarray, optional
 
-        training_target: Union['pandas.DataFrame', 'numpy.ndarray'], optional
-            Target/label data for the model
+        :param training_target: target/label data for the model
+        :type training_target: pandas.DataFrame or numpy.ndarray, optional
 
-        metadata: dictionary, optional
-            Model meta properties.
+        :param metadata: model meta properties
+        :type metadata: dict, optional
 
-        experiment_run_id: str, optional
-            ID of a training/experiment (only applicable for AutoAI deployments)
+        :param experiment_run_id: ID of a training/experiment (only applicable for AutoAI deployments)
+        :type experiment_run_id: str, optional
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.deployment import Batch
-        >>>
-        >>> deployment = Batch(
-        >>>        wml_credentials={
-        >>>              "apikey": "...",
-        >>>              "iam_apikey_description": "...",
-        >>>              "iam_apikey_name": "...",
-        >>>              "iam_role_crn": "...",
-        >>>              "iam_serviceid_crn": "...",
-        >>>              "instance_id": "...",
-        >>>              "url": "https://us-south.ml.cloud.ibm.com"
-        >>>            },
-        >>>         project_id="...",
-        >>>         space_id="...")
-        >>>
-        >>> deployment.create(
-        >>>        experiment_run_id="...",
-        >>>        model=model,
-        >>>        deployment_name='My new deployment'
-        >>>    )
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.deployment import Batch
+
+            deployment = Batch(
+                   wml_credentials={
+                         "apikey": "...",
+                         "iam_apikey_description": "...",
+                         "iam_apikey_name": "...",
+                         "iam_role_crn": "...",
+                         "iam_serviceid_crn": "...",
+                         "instance_id": "...",
+                         "url": "https://us-south.ml.cloud.ibm.com"
+                       },
+                    project_id="...",
+                    space_id="...")
+
+            deployment.create(
+                   experiment_run_id="...",
+                   model=model,
+                   deployment_name='My new deployment'
+               )
         """
         return super().create(model=model,
                               deployment_name=deployment_name,
@@ -176,48 +172,51 @@ class Batch(BaseDeployment):
                 output_data_reference: 'DataConnection' = None,
                 transaction_id: str = None,
                 background_mode: 'bool' = True) -> Union[Dict, Dict[str, List], DataConnection]:
-        """
-        Batch scoring job on WML. Payload or Payload data reference is required. It is passed to the WML where model have been deployed.
+        """Batch scoring job on WML. Payload or Payload data reference is required.
+        It is passed to the WML where model have been deployed.
 
-        Parameters
-        ----------
-        payload: pandas.DataFrame or List[DataConnection] or Dict, required
-            DataFrame that contains data to test the model or data storage connection details that inform the model where payload data is stored.
+        :param payload: DataFrame that contains data to test the model or data storage connection details
+            that inform the model where payload data is stored
+        :type payload: pandas.DataFrame or List[DataConnection] or Dict
 
-        output_data_reference: DataConnection, optional
-             DataConnection to the output COS for storing predictions.
-             Required only when DataConnections are used as a payload.
+        :param output_data_reference: DataConnection to the output COS for storing predictions,
+             required only when DataConnections are used as a payload
+        :type output_data_reference: DataConnection, optional
 
-        transaction_id: str, optional
-            Can be used to indicate under which id the records will be saved into payload table in IBM OpenScale.
+        :param transaction_id: can be used to indicate under which id the records will be saved into payload table
+            in IBM OpenScale
+        :type transaction_id: str, optional
 
-        background_mode: bool, optional
-            Indicator if score() method will run in background (async) or (sync).
+        :param background_mode: indicator if score() method will run in background (async) or (sync)
+        :type background_mode: bool, optional
 
-        Returns
-        -------
-        Dictionary with scoring job details.
+        :return: scoring job details
+        :rtype: dict
 
-        Example
-        -------
-        >>> score_details = batch_service.run_job(payload=test_data)
-        >>> print(score_details['entity']['scoring'])
-            {'input_data': [{'fields': ['sepal_length',
-                          'sepal_width',
-                          'petal_length',
-                          'petal_width'],
-                         'values': [[4.9, 3.0, 1.4, 0.2]]}],
-           'predictions': [{'fields': ['prediction', 'probability'],
-                         'values': [['setosa',
-                           [0.9999320742502246,
-                            5.1519823540224506e-05,
-                            1.6405926235405522e-05]]]}]
-        >>>
-        >>> payload_reference = DataConnection(location=DSLocation(asset_id=asset_id))
-        >>> score_details = batch_service.run_job(payload=payload_reference, output_data_filename = "scoring_output.csv")
-        >>> score_details = batch_service.run_job(payload={'observations': payload_reference})
-        >>> score_details = batch_service.run_job(payload=[payload_reference])
-        >>> score_details = batch_service.run_job(payload={'observations': payload_reference, 'supporting_features': supporting_features_reference})  # supporting features time series forecasting sceanrio
+        **Examples**
+
+        .. code-block:: python
+
+            score_details = batch_service.run_job(payload=test_data)
+            print(score_details['entity']['scoring'])
+
+            # Result:
+            # {'input_data': [{'fields': ['sepal_length',
+            #               'sepal_width',
+            #               'petal_length',
+            #               'petal_width'],
+            #              'values': [[4.9, 3.0, 1.4, 0.2]]}],
+            # 'predictions': [{'fields': ['prediction', 'probability'],
+            #               'values': [['setosa',
+            #                 [0.9999320742502246,
+            #                  5.1519823540224506e-05,
+            #                  1.6405926235405522e-05]]]}]
+
+            payload_reference = DataConnection(location=DSLocation(asset_id=asset_id))
+            score_details = batch_service.run_job(payload=payload_reference, output_data_filename = "scoring_output.csv")
+            score_details = batch_service.run_job(payload={'observations': payload_reference})
+            score_details = batch_service.run_job(payload=[payload_reference])
+            score_details = batch_service.run_job(payload={'observations': payload_reference, 'supporting_features': supporting_features_reference})  # supporting features time series forecasting sceanrio
         """
 
         if isinstance(payload, dict):
@@ -383,24 +382,22 @@ class Batch(BaseDeployment):
     def rerun_job(self,
                   scoring_job_id: str,
                   background_mode: bool = True) -> Union[dict, 'DataFrame', 'DataConnection']:
-        """
-        Rerun scoring job with the same parameters as job described by 'scoring_job_id'.
+        """Rerun scoring job with the same parameters as job described by `scoring_job_id`.
 
-        Parameters
-        ----------
-        scoring_job_id: str
-           Id described scoring job.
+        :param scoring_job_id: Id described scoring job
+        :type scoring_job_id: str
 
-        background_mode: bool, optional
-           Indicator if score_rerun() method will run in background (async) or (sync).
+        :param background_mode: indicator if score_rerun() method will run in background (async) or (sync)
+        :type background_mode: bool, optional
 
-        Returns
-        -------
-        Dictionary with scoring job details.
+        :return: scoring job details
+        :rtype: dict
 
-        Example
-        -------
-        >>> scoring_details = deployment.score_rerun(scoring_job_id)
+        **Example**
+
+        .. code-block:: python
+
+            scoring_details = deployment.score_rerun(scoring_job_id)
         """
         scoring_params = self.get_job_params(scoring_job_id)['entity']['scoring']
         input_data_references = self._target_workspace.wml_client.deployments.ScoringMetaNames.INPUT_DATA_REFERENCES
@@ -421,71 +418,65 @@ class Batch(BaseDeployment):
 
     @BaseDeployment._project_to_space_to_project
     def delete(self, deployment_id: str = None) -> None:
-        """
-        Delete deployment on WML.
+        """Delete deployment on WML.
 
-        Parameters
-        ----------
-        deployment_id: str, optional
-            ID of the deployment to delete. If empty, current deployment will be deleted.
+        :param deployment_id: ID of the deployment to delete, if empty, current deployment will be deleted
+        :type deployment_id: str, optional
 
-        Example
-        -------
-        >>> deployment = Batch(workspace=...)
-        >>> # Delete current deployment
-        >>> deployment.delete()
-        >>> # Or delete a specific deployment
-        >>> deployment.delete(deployment_id='...')
+        **Example**
+
+        .. code-block:: python
+
+            deployment = Batch(workspace=...)
+            # Delete current deployment
+            deployment.delete()
+            # Or delete a specific deployment
+            deployment.delete(deployment_id='...')
         """
         super().delete(deployment_id=deployment_id, deployment_type='batch')
 
     @BaseDeployment._project_to_space_to_project
     def list(self, limit=None) -> 'DataFrame':
-        """
-        List WML deployments.
+        """List WML deployments.
 
-        Parameters
-        ----------
-        limit: int, optional
-            Set the limit of how many deployments to list. Default is None (all deployments should be fetched)
+        :param limit: set the limit of how many deployments to list,
+            default is `None` (all deployments should be fetched)
+        :type limit: int, optional
 
-        Returns
-        -------
-        Pandas DataFrame with information about deployments.
+        :return: Pandas DataFrame with information about deployments
+        :rtype: pandas.DataFrame
 
-        Example
-        -------
-        >>> deployment = Batch(workspace=...)
-        >>> deployments_list = deployment.list()
-        >>> print(deployments_list)
-                             created_at  ...  status
-            0  2020-03-06T10:50:49.401Z  ...   ready
-            1  2020-03-06T13:16:09.789Z  ...   ready
-            4  2020-03-11T14:46:36.035Z  ...  failed
-            3  2020-03-11T14:49:55.052Z  ...  failed
-            2  2020-03-11T15:13:53.708Z  ...   ready
+        **Example**
+
+        .. code-block:: python
+
+            deployment = Batch(workspace=...)
+            deployments_list = deployment.list()
+            print(deployments_list)
+
+            # Result:
+            #                  created_at  ...  status
+            # 0  2020-03-06T10:50:49.401Z  ...   ready
+            # 1  2020-03-06T13:16:09.789Z  ...   ready
+            # 4  2020-03-11T14:46:36.035Z  ...  failed
+            # 3  2020-03-11T14:49:55.052Z  ...  failed
+            # 2  2020-03-11T15:13:53.708Z  ...   ready
         """
         return super().list(limit=limit, deployment_type='batch')
 
     @BaseDeployment._project_to_space_to_project
     def get(self, deployment_id: str) -> None:
-        """
-        Get WML deployment.
+        """Get WML deployment.
 
+        :param deployment_id: ID of the deployment to work with
+        :type deployment_id: str
 
-        Parameters
-        ----------
-        deployment_id: str, required
-            ID of the deployment to work with.
+        **Example**
 
-        Returns
-        -------
-        WebService deployment object
+        .. code-block:: python
 
-        Example
-        -------
-        >>> deployment = Batch(workspace=...)
-        >>> deployment.get(deployment_id="...")
+            deployment = Batch(workspace=...)
+            deployment.get(deployment_id="...")
         """
         super().get(deployment_id=deployment_id, deployment_type='batch')
 
@@ -493,30 +484,24 @@ class Batch(BaseDeployment):
     def get_job_params(self, scoring_job_id: str = None) -> Dict:
         """Get batch deployment job parameters.
 
-        Parameters
-        ----------
-        scoring_job_id: str
-           Id of scoring job.
+        :param scoring_job_id: Id of scoring job
+        :type scoring_job_id: str
 
-        Returns
-        -------
-        Dictionary with parameters of the scoring job.
-           """
+        :return: parameters of the scoring job
+        :rtype: dict
+        """
         return self._target_workspace.wml_client.deployments.get_job_details(scoring_job_id)
 
     @BaseDeployment._project_to_space_to_project
     def get_job_status(self, scoring_job_id: str) -> Dict:
         """Get status of scoring job.
 
-        Parameters
-        ----------
-        scoring_job_id: str
-           Id of scoring job.
+        :param scoring_job_id: Id of scoring job
+        :type scoring_job_id: str
 
-        Returns
-        -------
-        Dictionary with state of scoring job (one of: [completed, failed, starting, queued])
-            and additional details if they exist.
+        :return: dictionary with state of scoring job (one of: [completed, failed, starting, queued])
+            and additional details if they exist
+        :rtype: dict
         """
         return self._target_workspace.wml_client.deployments.get_job_status(scoring_job_id)
 
@@ -524,15 +509,14 @@ class Batch(BaseDeployment):
     def get_job_result(self, scoring_job_id: str) -> 'DataFrame':
         """Get batch deployment results of job with id `scoring_job_id`.
 
-        Parameters
-        ----------
-        scoring_job_id: str
-           Id of scoring job which results will be returned.
+        :param scoring_job_id: Id of scoring job which results will be returned
+        :type scoring_job_id: str
 
-        Returns
-        -------
-        DataFrame with result.
-            In case of incompleted or failed `MissingScoringResults` scoring exception is raised.
+        :return: result
+        :rtype: pandas.DataFrame
+
+        :raises MissingScoringResults: in case of incompleted or failed job
+            `MissingScoringResults` scoring exception is raised
         """
         scoring_params = self.get_job_params(scoring_job_id)['entity']['scoring']
         if scoring_params['status']['state'] == 'completed':
@@ -581,22 +565,19 @@ class Batch(BaseDeployment):
                 serving_name=None, # Not used, but added to match unified parameters for _deploy
                 result_client=None,
                 hardware_spec=None) -> Dict: # Not used, but added to match unified parameters for _deploy
-        """
-        Deploy model into WML.
+        """Deploy model into WML.
 
-        Parameters
-        ----------
-        pipeline_model: Union['Pipeline', str], required
-            Model of the pipeline to deploy
+        :param pipeline_model: model of the pipeline to deploy
+        :type pipeline_model: Pipeline or str
 
-        deployment_name: str, required
-            Name of the deployment
+        :param deployment_name: name of the deployment
+        :type deployment_name: str
 
-        meta_props: dictionary, required
-            Model meta properties.
+        :param meta_props: model meta properties
+        :type meta_props: dict
 
-        result_client: Tuple['DataConnection', 'resource'] required
-            Tuple with Result DataConnection object and initialized COS client.
+        :param result_client: tuple with Result DataConnection object and initialized COS client
+        :type result_client: tuple[DataConnection, resource]
         """
         deployment_details = {}
         asset_uid = self._publish_model(pipeline_model=pipeline_model,
