@@ -1,4 +1,4 @@
-#  (C) Copyright IBM Corp. 2021.
+#  (C) Copyright IBM Corp. 2021-2023.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -174,8 +174,8 @@ class AutoAI(BaseExperiment):
                   include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms',
                                                       'ForecastingAlgorithms', 'TimeseriesAnomalyPredictionAlgorithms']] = None,
                   daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,  # deprecated
-                  #include_batched_ensemble_estimators: List[Union['BatchedClassificationAlgorithms',
-                  #                                                'BatchedRegressionAlgorithms']] = None,
+                  include_batched_ensemble_estimators: List[Union['BatchedClassificationAlgorithms',
+                                                                  'BatchedRegressionAlgorithms']] = None,
                   backtest_num: int = None,
                   lookback_window: int = None,
                   forecast_window: int = None,
@@ -254,6 +254,11 @@ class AutoAI(BaseExperiment):
         :type train_sample_rows_test_size: float, optional
 
         :param daub_include_only_estimators: deprecated, use `include_only_estimators` instead
+        
+        :param include_batched_ensemble_estimators: list of batched ensemble estimators to include 
+            in computation process, see: AutoAI.BatchedClassificationAlgorithms, AutoAI.BatchedRegressionAlgorithms
+        :type include_batched_ensemble_estimators: 
+            list[BatchedClassificationAlgorithms or BatchedRegressionAlgorithms], optional
 
         :param include_only_estimators: list of estimators to include in computation process, see:
             AutoAI.ClassificationAlgorithms, AutoAI.RegressionAlgorithms or AutoAI.ForecastingAlgorithms
@@ -377,115 +382,101 @@ class AutoAI(BaseExperiment):
             - ImputationStrategy.NEXT
             - ImputationStrategy.NO_IMPUTATION
 
-        numerical_imputation_value: float, optional
-            Value for filling missing values if numerical_imputation_strategy is set to ImputationStrategy.VALUE.
-            For forecasting only.
+        :param numerical_imputation_value: value for filling missing values if numerical_imputation_strategy
+            is set to ImputationStrategy.VALUE, for forecasting only
+        :type numerical_imputation_value: float, optional
 
-        imputation_threshold: float, optional
-            Maximum threshold of missing values imputation.
-            For forecasting only.
+        :param imputation_threshold: maximum threshold of missing values imputation, for forecasting only
+        :type imputation_threshold: float, optional
 
-        retrain_on_holdout: bool, optional
-            If True final pipelines will be train also on holdout data.
+        :param retrain_on_holdout: if True final pipelines will be train also on holdout data
+        :type retrain_on_holdout: bool, optional
 
-        categorical_columns: list, optional
-            List of columns names that must be treated as categorical.
+        :param categorical_columns: list of columns names that must be treated as categorical
+        :type categorical_columns: list, optional
 
-        numerical_columns: list, optional
-            List of columns names that must be treated as numerical.
+        :param numerical_columns: list of columns names that must be treated as numerical
+        :type numerical_columns: list, optional
 
-        sampling_type: str, optional
-            Type of sampling data for training. One of SamplingTypes enum values.
-            Default is SamplingTypes.FIRST_N_RECORDS.
-            Supported only for IBM Cloud Pak® for Data 4.0.1 and above.
+        :param sampling_type: type of sampling data for training, one of SamplingTypes enum values,
+            default is SamplingTypes.FIRST_N_RECORDS, supported only for IBM Cloud Pak® for Data 4.0.1 and above
+        :type sampling_type: str, optional
 
-        sample_size_limit: int, optional
-            The size of sample upper bound (in bytes). The default value is 1GB.
-            Supported only for IBM Cloud Pak® for Data 4.5 and above.
+        :param sample_size_limit: the size of sample upper bound (in bytes). The default value is 1GB,
+            supported only for IBM Cloud Pak® for Data 4.5 and above
+        :type sample_size_limit: int, optional
 
-        sample_rows_limit: int, optional
-            The size of sample upper bound (in rows).
-            Supported only for IBM Cloud Pak® for Data 4.6 and above.
+        :param sample_rows_limit: the size of sample upper bound (in rows),
+            supported only for IBM Cloud Pak® for Data 4.6 and above
+        :type sample_rows_limit: int, optional
 
-        sample_percentage_limit: float, optional
-            The size of sample upper bound (as fraction of dataset size).
-            Supported only for IBM Cloud Pak® for Data 4.6 and above.
+        :param sample_percentage_limit: the size of sample upper bound (as fraction of dataset size),
+            supported only for IBM Cloud Pak® for Data 4.6 and above
+        :type sample_percentage_limit: float, optional
 
-        number_of_batch_rows: int, optional
-            Number of rows to read in each batch when reading from flight connection.
+        :param number_of_batch_rows: number of rows to read in each batch when reading from flight connection
+        :type number_of_batch_rows: int, optional
 
-        test_data_csv_separator: Union[List[str], str], optional
-            The separator, or list of separators to try for separating
-            columns in a CSV user-defined holdout/test file.  Not used if the file_name is not a CSV file.
-            Default is ','.
+        :param test_data_csv_separator: the separator, or list of separators to try for separating
+            columns in a CSV user-defined holdout/test file, not used if the file_name is not a CSV file,
+            default is ','
+        :type test_data_csv_separator: list[str] or str, optional
 
-        test_data_excel_sheet: Union[str, int], optional
-            Name of the excel sheet to use for user-defined holdout/test data. Only use when xlsx file is an test
-            dataset file. By default first sheet is used.
+        :param test_data_excel_sheet: name of the excel sheet to use for user-defined holdout/test data, 
+            only use when xlsx file is an test, dataset file, by default first sheet is used
+        :type test_data_excel_sheet: str or int, optional
 
-        test_data_encoding: str, optional
-            Encoding type for CSV user-defined holdout/test file.
+        :param test_data_encoding: encoding type for CSV user-defined holdout/test file
+        :type test_data_encoding: str, optional
 
-        confidence_level: float, optional for timeseries anomaly prediction
-            When the pipeline "PointwiseBoundedHoltWinters" or "PointwiseBoundedBATS" is used, the prediction interval
-            is calculated at a given confidence_level to decide if a data record is an anomaly or not.
+        :param confidence_level: when the pipeline "PointwiseBoundedHoltWinters" or "PointwiseBoundedBATS" is used, 
+            the prediction interval is calculated at a given confidence_level to decide if a data record 
+            is an anomaly or not, optional for timeseries anomaly prediction
+        :type confidence_level: float, optional
 
 
-        Returns
-        -------
-        RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object.
+        :return: RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object
+        :rtype: RemoteAutoPipelines or LocalAutoPipelines
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(...)
-        >>>
-        >>> fairness_info = {
-        >>>            "protected_attributes": [
-        >>>                {"feature": "Sex", "reference_group": ['male'], "monitored_group": ['female']},
-        >>>                {"feature": "Age", "reference_group": [[50,60]], "monitored_group": [[18, 49]]}
-        >>>            ],
-        >>>            "favorable_labels": ["No Risk"],
-        >>>            "unfavorable_labels": ["Risk"],
-        >>>            }
-        >>>
-        >>> optimizer = experiment.optimizer(
-        >>>        name="name of the optimizer.",
-        >>>        prediction_type=AutoAI.PredictionType.BINARY,
-        >>>        prediction_column="y",
-        >>>        scoring=AutoAI.Metrics.ROC_AUC_SCORE,
-        >>>        desc="Some description.",
-        >>>        holdout_size=0.1,
-        >>>        max_num_daub_ensembles=1,
-        >>>        fairness_info= fairness_info,
-        >>>        cognito_transform_names=[AutoAI.Transformers.SUM,AutoAI.Transformers.MAX],
-        >>>        train_sample_rows_test_size=1,
-        >>>        include_only_estimators=[AutoAI.ClassificationAlgorithms.LGBM, AutoAI.ClassificationAlgorithms.XGB],
-        >>>        t_shirt_size=AutoAI.TShirtSize.L
-        >>>    )
-        >>>
-        >>> optimizer = experiment.optimizer(
-        >>>        name="name of the optimizer.",
-        >>>        prediction_type=AutoAI.PredictionType.MULTICLASS,
-        >>>        prediction_column="y",
-        >>>        scoring=AutoAI.Metrics.ROC_AUC_SCORE,
-        >>>        desc="Some description.",
-        >>>    )
+        **Examples**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(...)
+
+            fairness_info = {
+                       "protected_attributes": [
+                           {"feature": "Sex", "reference_group": ['male'], "monitored_group": ['female']},
+                           {"feature": "Age", "reference_group": [[50,60]], "monitored_group": [[18, 49]]}
+                       ],
+                       "favorable_labels": ["No Risk"],
+                       "unfavorable_labels": ["Risk"],
+                       }
+
+            optimizer = experiment.optimizer(
+                   name="name of the optimizer.",
+                   prediction_type=AutoAI.PredictionType.BINARY,
+                   prediction_column="y",
+                   scoring=AutoAI.Metrics.ROC_AUC_SCORE,
+                   desc="Some description.",
+                   holdout_size=0.1,
+                   max_num_daub_ensembles=1,
+                   fairness_info= fairness_info,
+                   cognito_transform_names=[AutoAI.Transformers.SUM,AutoAI.Transformers.MAX],
+                   train_sample_rows_test_size=1,
+                   include_only_estimators=[AutoAI.ClassificationAlgorithms.LGBM, AutoAI.ClassificationAlgorithms.XGB],
+                   t_shirt_size=AutoAI.TShirtSize.L
+               )
+
+            optimizer = experiment.optimizer(
+                   name="name of the optimizer.",
+                   prediction_type=AutoAI.PredictionType.MULTICLASS,
+                   prediction_column="y",
+                   scoring=AutoAI.Metrics.ROC_AUC_SCORE,
+                   desc="Some description.",
+               )
         """
-
-        # Docs for include_batched_ensemble_estimators:
-        # include_batched_ensemble_estimators: List[
-        #     Union['BatchedClassificationAlgorithms', 'BatchedRegressionAlgorithms']], optional
-        # List of batched ensemble estimators to include in computation process.
-        #
-        # See: AutoAI.BatchedClassificationAlgorithms, AutoAI.BatchedRegressionAlgorithms
-
-        include_batched_ensemble_estimators = None
-        if 'include_batched_ensemble_estimators' in kwargs:
-            include_batched_ensemble_estimators = kwargs.pop('include_batched_ensemble_estimators')  # TODO to be removed
-        elif 'global_stage_include_batched_ensemble_estimators' in kwargs:
-            include_batched_ensemble_estimators = kwargs.pop('global_stage_include_batched_ensemble_estimators')  # TODO to be removed
-
         # note: convert `timeseries` type to PredictionType.FORECASTING:
         if prediction_type == 'timeseries':
             prediction_type = PredictionType.FORECASTING
