@@ -1,4 +1,4 @@
-#  (C) Copyright IBM Corp. 2021.
+#  (C) Copyright IBM Corp. 2021-2023.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -1196,4 +1196,4 @@ class WMLEngine(BaseEngine):
         :rtype: tuple[Pipeline, bool]
         """
         best_pipeline_name = self.summary().index[0]
-        return self.get_pipeline(best_pipeline_name)
+        return self.get_pipeline(best_pipeline_name, persist=persist)
