@@ -1,4 +1,4 @@
-#  (C) Copyright IBM Corp. 2021.
+#  (C) Copyright IBM Corp. 2021-2023.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -133,7 +133,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  t_shirt_size: 'TShirtSize' = TShirtSize.M,
                  train_sample_rows_test_size: float = None,
                  include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
-                 include_batched_ensemble_estimators: List[Union['BatchedClassificationAlgorithms', 'BatchedRegressionAlgorithms']] = None,
+                 include_batched_ensemble_estimators: List[Union['BatchedClassificationAlgorithms',
+                                                                 'BatchedRegressionAlgorithms']] = None,
                  backtest_num: int = None,
                  lookback_window: int = None,
                  forecast_window: int = None,
