@@ -2,7 +2,7 @@ __all__ = [
     "AutoPipelinesRuns"
 ]
 
-#  (C) Copyright IBM Corp. 2021.
+#  (C) Copyright IBM Corp. 2021-2023.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -199,8 +199,8 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'prediction_column': kb_parameters.get('label'),
                 'prediction_columns': kb_parameters.get('target_columns'),
                 'timestamp_column_name': kb_parameters.get('timestamp_column'),
-                'holdout_size': kb_parameters['holdout_param'],
-                'max_num_daub_ensembles': kb_parameters['max_num_daub_ensembles'],
+                'holdout_size': kb_parameters.get('holdout_param'),
+                'max_num_daub_ensembles': kb_parameters.get('max_num_daub_ensembles'),
                 't_shirt_size': kb_wml_data['hardware_spec']['id'],
                 'include_only_estimators': kb_parameters.get('daub_include_only_estimators'),
                 'cognito_transform_names': kb_parameters.get('cognito_transform_names'),
