@@ -538,6 +538,6 @@ class XGBClassifierLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
 
         :param: payload: dict
         """
-        return (payload['func'] == 'update_grad')
+        return (payload['func'] == 'update_raw_preds')
 
 
